@@ -72,26 +72,33 @@ class AddOrganizationNodeResponse(AbstractModel):
 
 
 class AuthNode(AbstractModel):
-    """认证主体主要信息
+    """互信主体主要信息
 
     """
 
     def __init__(self):
         r"""
-        :param RelationId: 主体关系ID
+        :param RelationId: 互信主体关系ID
 注意：此字段可能返回 null，表示取不到有效值。
         :type RelationId: int
-        :param AuthName: 主体名称
+        :param AuthName: 互信主体名称
 注意：此字段可能返回 null，表示取不到有效值。
         :type AuthName: str
+        :param Manager: 主体管理员
+注意：此字段可能返回 null，表示取不到有效值。
+        :type Manager: :class:`tencentcloud.organization.v20210331.models.MemberMainInfo`
         """
         self.RelationId = None
         self.AuthName = None
+        self.Manager = None
 
 
     def _deserialize(self, params):
         self.RelationId = params.get("RelationId")
         self.AuthName = params.get("AuthName")
+        if params.get("Manager") is not None:
+            self.Manager = MemberMainInfo()
+            self.Manager._deserialize(params.get("Manager"))
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -432,14 +439,18 @@ class DescribeOrganizationAuthNodeRequest(AbstractModel):
         :type Offset: int
         :param Limit: 限制数目。最大50
         :type Limit: int
+        :param AuthName: 互信主体名称。
+        :type AuthName: str
         """
         self.Offset = None
         self.Limit = None
+        self.AuthName = None
 
 
     def _deserialize(self, params):
         self.Offset = params.get("Offset")
         self.Limit = params.get("Limit")
+        self.AuthName = params.get("AuthName")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -556,9 +567,9 @@ class DescribeOrganizationMemberAuthIdentitiesRequest(AbstractModel):
 
     def __init__(self):
         r"""
-        :param Offset: 偏移量。
+        :param Offset: 偏移量。取值是limit的整数倍，默认值 : 0
         :type Offset: int
-        :param Limit: 限制数目。最大50
+        :param Limit: 限制数目。取值范围：1~50，默认值：10
         :type Limit: int
         :param MemberUin: 组织成员Uin。
         :type MemberUin: int
@@ -588,7 +599,7 @@ class DescribeOrganizationMemberAuthIdentitiesResponse(AbstractModel):
 
     def __init__(self):
         r"""
-        :param Items: 列表。
+        :param Items: 授权身份列表。
 注意：此字段可能返回 null，表示取不到有效值。
         :type Items: list of OrgMemberAuthIdentity
         :param Total: 总数目。
@@ -688,9 +699,9 @@ class DescribeOrganizationMembersRequest(AbstractModel):
 
     def __init__(self):
         r"""
-        :param Offset: 偏移量。
+        :param Offset: 偏移量。取值是limit的整数倍，默认值 : 0
         :type Offset: int
-        :param Limit: 限制数目。最大50
+        :param Limit: 限制数目。取值范围：1~50，默认值：10
         :type Limit: int
         :param Lang: 国际站：en，国内站：zh
         :type Lang: str
@@ -980,19 +991,22 @@ class ListOrganizationIdentityRequest(AbstractModel):
 
     def __init__(self):
         r"""
-        :param Offset: 偏移量。
+        :param Offset: 偏移量。取值是limit的整数倍。默认值 : 0。
         :type Offset: int
-        :param Limit: 限制数目。最大50
+        :param Limit: 限制数目。取值范围：1~50。默认值：10。
         :type Limit: int
         :param SearchKey: 名称搜索关键字。
         :type SearchKey: str
         :param IdentityId: 身份ID搜索。
         :type IdentityId: int
+        :param IdentityType: 身份类型。取值范围 1-预设, 2-自定义
+        :type IdentityType: int
         """
         self.Offset = None
         self.Limit = None
         self.SearchKey = None
         self.IdentityId = None
+        self.IdentityType = None
 
 
     def _deserialize(self, params):
@@ -1000,6 +1014,7 @@ class ListOrganizationIdentityRequest(AbstractModel):
         self.Limit = params.get("Limit")
         self.SearchKey = params.get("SearchKey")
         self.IdentityId = params.get("IdentityId")
+        self.IdentityType = params.get("IdentityType")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -1071,6 +1086,36 @@ class MemberIdentity(AbstractModel):
         
 
 
+class MemberMainInfo(AbstractModel):
+    """成员主要信息
+
+    """
+
+    def __init__(self):
+        r"""
+        :param MemberUin: 成员uin
+注意：此字段可能返回 null，表示取不到有效值。
+        :type MemberUin: int
+        :param MemberName: 成员名称j
+注意：此字段可能返回 null，表示取不到有效值。
+        :type MemberName: str
+        """
+        self.MemberUin = None
+        self.MemberName = None
+
+
+    def _deserialize(self, params):
+        self.MemberUin = params.get("MemberUin")
+        self.MemberName = params.get("MemberName")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
 class MoveOrganizationNodeMembersRequest(AbstractModel):
     """MoveOrganizationNodeMembers请求参数结构体
 
@@ -1361,13 +1406,13 @@ class OrgMemberAuthIdentity(AbstractModel):
         :param IdentityId: 身份ID。
 注意：此字段可能返回 null，表示取不到有效值。
         :type IdentityId: int
-        :param IdentityRoleName: 身份角色名。
+        :param IdentityRoleName: 身份的角色名。
 注意：此字段可能返回 null，表示取不到有效值。
         :type IdentityRoleName: str
-        :param IdentityRoleAliasName: 身份角色别名。
+        :param IdentityRoleAliasName: 身份的角色别名。
 注意：此字段可能返回 null，表示取不到有效值。
         :type IdentityRoleAliasName: str
-        :param Description: 描述
+        :param Description: 描述。
 注意：此字段可能返回 null，表示取不到有效值。
         :type Description: str
         :param CreateTime: 创建时间。
@@ -1376,6 +1421,9 @@ class OrgMemberAuthIdentity(AbstractModel):
         :param UpdateTime: 更新时间。
 注意：此字段可能返回 null，表示取不到有效值。
         :type UpdateTime: str
+        :param IdentityType: 身份类型。取值： 1-预设  2-自定义
+注意：此字段可能返回 null，表示取不到有效值。
+        :type IdentityType: int
         """
         self.IdentityId = None
         self.IdentityRoleName = None
@@ -1383,6 +1431,7 @@ class OrgMemberAuthIdentity(AbstractModel):
         self.Description = None
         self.CreateTime = None
         self.UpdateTime = None
+        self.IdentityType = None
 
 
     def _deserialize(self, params):
@@ -1392,6 +1441,7 @@ class OrgMemberAuthIdentity(AbstractModel):
         self.Description = params.get("Description")
         self.CreateTime = params.get("CreateTime")
         self.UpdateTime = params.get("UpdateTime")
+        self.IdentityType = params.get("IdentityType")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
